@@ -1,9 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-Created on Thu Aug 22 20:53:05 2019
-
-@author: Dror
-
 TODO
 do we need all these functions as static?
 some may be instance functions, some may belong in utils.
@@ -14,6 +10,7 @@ import copy
 
 import numpy as np
 
+from gensound.settings import _supported
 from gensound.utils import sec, sample_rates
 
 
@@ -186,7 +183,7 @@ class Audio:
         [TODO does this have to be a supported sample rate?]
         """
         if sample_rate not in sample_rates:
-            warnings.warn("Resampling audio to sample rate which is not supported in playback. "
+            warnings.warn("Resampling audio to non-standard sample rate. "
                           "This is totally fine if you know what you're doing.")
         
         if self.sample_rate == sample_rate:
@@ -378,34 +375,34 @@ class Audio:
         self.buffer = audio_to_bytes(self.audio, ["uint8","int16","int24","int32"][byte_width-1])
         
         
-    def play(self, byte_width=2, max_amplitude=None, is_wait=True):
-        from gensound.io import play_Audio
+    def play(self, byte_width=2, max_amplitude=None, **kwargs):
+        from gensound.io import IO
         
         self._prepare_buffer(byte_width, max_amplitude) # TODO max amplitude
-        play_Audio(self, is_wait)
-    
-    @staticmethod
-    def from_WAV(filename):
-        warnings.warn("Audio.from_WAV to be deprecated; use Audio.from_file instead.")
-        return Audio.from_file(filename, file_format="wav")
+        return IO.play(self, **kwargs)
     
     @staticmethod
     def from_file(filename, file_format=None): # 2nd argument to force format regardless of file name
+        from gensound.io import IO
+        
         ext = file_format or filename.split(".")[-1].lower()
         
         if ext in ("wav", "wave"):
-            from gensound.io import WAV_to_Audio
-            return WAV_to_Audio(filename)
+            return IO.WAV_to_Audio(filename)
         
         if ext in ("aiff", "aifc", "aif"):
-            from gensound.io import AIFF_to_Audio
-            return AIFF_to_Audio(filename)
+            return IO.AIFF_to_Audio(filename)
+        
+        # TODO testing
+        return IO.file_to_Audio(filename) # catch-all
     
     def to_WAV(self, filename, byte_width=2, max_amplitude=1):
         warnings.warn("Audio.to_WAV to be deprecated; use Audio.export instead.")
         self.export(filename, byte_width, max_amplitude, file_format="wav")
     
     def export(self, filename, byte_width=2, max_amplitude=None, file_format=None):
+        from gensound.io import IO
+        
         ext = file_format or filename.split(".")[-1].lower()
         
         self._prepare_buffer(byte_width, max_amplitude)
@@ -415,13 +412,23 @@ class Audio:
         # since the latter is not supposed to hold a buffer nor byte width
         
         if ext in ("wav", "wave"):
-            from gensound.io import export_WAV
-            export_WAV(filename, self)
-        
-        if ext in ("aiff", "aifc", "aif"):
-            from gensound.io import export_AIFF
-            export_AIFF(filename, self)
-
+            IO.export_WAV(filename, self)
+        elif ext in ("aiff", "aifc", "aif"):
+            IO.export_AIFF(filename, self)
+        else:
+            IO.export_file(filename, self)
+    
+    
+    
+    
+    ###### visualisations ########
+    
+    def plot(self):
+        assert "matplotlib" in _supported, "matplotlib missing, Audio.plot() not available."
+        import gensound.visualise
+        gensound.visualise._plot_audio(self)
+    
+    
 
 
 
