@@ -1,9 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-Created on Sat Aug 17 21:41:28 2019
-
-@author: Dror
-"""
 
 import copy
 
@@ -57,7 +52,7 @@ class Signal:
     
     def play(self, sample_rate=44100, **kwargs):
         audio = self.realise(sample_rate)
-        audio.play(**kwargs)
+        return audio.play(**kwargs)
     
     def export(self, filename, sample_rate=44100, **kwargs):
         audio = self.realise(sample_rate)
