@@ -1,11 +1,7 @@
 # -*- coding: utf-8 -*-
-"""
-Created on Sun Aug 18 21:01:16 2019
-
-@author: Dror
-"""
 
 import numpy as np
+
 from gensound.settings import _supported
 from gensound.curve import Curve, Line, Logistic, Constant
 from gensound.audio import Audio
@@ -130,7 +126,7 @@ class Combine(Transform):
     def __init__(self, channel_slice, time_slice, signal):
         self.channel_slice = channel_slice # slices of container Signal
         self.time_slice = time_slice
-        self.signal = signal # inserted Signal
+        self.signal = signal.copy() # inserted Signal
     
     def realise(self, audio):
         # prepare new audio and ensure shift can only be negative
@@ -192,7 +188,7 @@ class Fade(Transform):
     This is the superclass of FadeIn and FadeOut; use those instead.
     """
     def __init__(self, is_in=True, duration=1e3, curve="linear", *,  degree=2):
-        assert curve in ("linear", "polynomial")
+        assert curve in ("linear", "polynomial", "exponential")
         self.is_in = is_in
         self.duration = duration
         self.curve = curve
@@ -203,6 +199,17 @@ class Fade(Transform):
             amp = np.linspace(0, 1, self.num_samples(audio.sample_rate))
         elif self.curve == "polynomial":
             amp = (np.linspace(0, 1, self.num_samples(audio.sample_rate))) ** self.degree
+        elif self.curve == "exponential":
+            if self.degree == 0: # reverts to linear:
+                amp = np.linspace(0, 1, self.num_samples(audio.sample_rate))
+            else:
+                amp = np.linspace(0, 1, self.num_samples(audio.sample_rate))
+                d = DB_to_Linear(self.degree) # TODO
+                env = d**(1-amp)
+                amp = (env - d)/(1-d)
+            # TODO eaqsier to use (e**(kx) - 1)/(e**k - 1) for some k
+            # then k > 0 is like polynomial of degree > 1
+            # k < 0 is like polynomial of degree < 1
         
         # fade in/out handler
         if self.is_in:
@@ -229,19 +236,15 @@ class FadeOut(Fade):
 
 
 class CrossFade(BiTransform): # TODO rename to XFade?
-    def __init__(self, *args, **kwargs):
+    def __init__(self, duration=1e3, **kwargs):
         # different default values for crossfade, to ensure equal power
         if "curve" not in kwargs:
             kwargs["curve"] = "polynomial"
         if "degree" not in kwargs:
             kwargs["degree"] = 0.5
         
-        if "duration" in kwargs:
-            args = (kwargs["duration"],) + args # hackish, maybe there's a better way
-            del kwargs["duration"]
-        
-        L = FadeOut(*args, **kwargs)
-        R = FadeIn(*args, **kwargs)*Shift(-args[0]) # args[0] is duration
+        L = FadeOut(duration, **kwargs)
+        R = FadeIn(duration, **kwargs)*Shift(-duration)
         super().__init__(L, R)
 
 
